package com.xylink.sdk;

import com.xylink.util.Result;

import java.io.IOException;

/**
 * @Classname SdkMethod
 * @Date 2022/4/6 10:39 上午
 * @Created by anan
 * @Description sdkjar 通用方法，用于用户调用SDKserver的接口，用户需要传入url，body以及选择正确的请求方法即可
 * url的形式如下：/api/rest/xxx?xxx=xxxxx
 * 需要事先进行初始化
 * <p>
 * #####################
 * 需要使用签名算法2.0   #
 * ####################
 */
public class SdkMethodV2 extends SdkMethodV1 {

    /**
     * 使用签名2.0方法
     *
     * @param url /api/rest/xxx?xxx=xxxxx,不包含&signature=XXX
     * @return 返回文档描述中的对象
     * @throws IOException 抛出异常
     */
    public static <T> Result<T> sdkGet(String url, Class<T> responseType) throws IOException {
        return SdkMethodV2.sdkGet(url, null, responseType);
    }

    /**
     * 签名2.0方法
     *
     * @param url  /api/rest/xxx?xxx=xxxxx,不包含&signature=XXX
     * @param body 文档描述中的body内容
     * @return 返回文档描述中的对象
     * @throws IOException 抛出异常
     */
    public static <T> Result<T> sdkPost(String url, Object body, Class<T> responseType) throws IOException {
        return SdkMethodV2.sdkPost(url, null, body, responseType);
    }

    /**
     * 签名2.0方法
     *
     * @param url  /api/rest/xxx?xxx=xxxxx,不包含&signature=XXX
     * @param body 文档描述中的body内容
     * @return 返回文档描述中的对象
     * @throws IOException 抛出异常
     */
    public static <T> Result<T> sdkPut(String url, Object body, Class<T> responseType) throws IOException {
        return SdkMethodV2.sdkPut(url, null, body, responseType);
    }

    /**
     * 签名2.0
     *
     * @param url /api/rest/xxx?xxx=xxxxx,不包含&signature=XXX
     * @return 返回文档描述中的对象
     * @throws IOException 抛出异常
     */
    public static <T> Result<T> sdkDelete(String url, Class<T> responseType) throws IOException {
        return SdkMethodV2.sdkDelete(url, null, responseType);
    }
}
