package com.xylink.sdk.wechat;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.config.SDKConfigMgr;
import com.xylink.model.*;
import com.xylink.util.HttpUtil;
import com.xylink.util.Result;
import com.xylink.util.SignatureSample;
import java.io.IOException;
import java.util.List;

/**
 * Created with IntelliJ IDEA.
 * Description:
 * User: gzm
 * Date: 2018-12-08
 */
public class MiniProgramApi {
    private static SignatureSample signatureSample = new SignatureSample();
    private static final String prefixUrl = "/api/rest/external/v1/";

    public Result<List<SdkMiniProgramUserDto>> batchUser(String enterpriseId, String token, String appId) throws IOException {
        String surl = getPrefixUrl() + "miniprogram/batch/users?enterpriseId="+enterpriseId +"&appId=" + appId ;
        String signature = signatureSample.computeSignature("","POST",token,surl);
        surl += "&signature=" + signature;
        try {
            Result<List<SdkMiniProgramUserDto>> SdkMiniProgramUserDtos = HttpUtil.getResponse(surl, "POST", null, List.class);
            if(SdkMiniProgramUserDtos.isSuccess()) {
                return SdkMiniProgramUserDtos;
            } else {
                throw new RuntimeException(SdkMiniProgramUserDtos.getErrorStatus() + "");
            }
        } catch (IOException e) {
            throw e;
        }
    }

    public Result getToken(String enterpriseId, String token, SdkMiniProgramTokenRequestModel sdkMiniProgramTokenRequestModel) throws IOException {
        String surl = getPrefixUrl() + "miniprogram/token?enterpriseId="+enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(sdkMiniProgramTokenRequestModel);
        String signature = signatureSample.computeSignature(jsonEntity,"PUT",token,surl);
        surl += "&signature=" + signature;
        try {
            return HttpUtil.getResponse(surl, "PUT", jsonEntity, String.class);
        } catch (IOException e) {
            throw e;
        }
    }

    public Result tokenLogin(String enterpriseId, String token, SdkMiniProgramLoginRequest sdkMiniProgramLoginRequest) throws IOException {
        String surl = getPrefixUrl() + "en/miniprogram/login?enterpriseId="+enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(sdkMiniProgramLoginRequest);
//        String signature = signatureSample.computeSignature(jsonEntity,"PUT",token,surl);
//        surl += "&signature=" + signature;
        try {
            return HttpUtil.getResponse(surl, "PUT", jsonEntity, String.class);
        } catch (IOException e) {
            throw e;
        }
    }

    public Result getUsers(String enterpriseId, String token, String appId) throws IOException {
        String surl = getPrefixUrl() + "miniprogram/users?enterpriseId="+enterpriseId+"&appId="+appId;
        String jsonEntity = "";
        String signature = signatureSample.computeSignature(jsonEntity,"GET",token,surl);
        surl += "&signature=" + signature;
        try {
            return HttpUtil.getResponse(surl, "GET", jsonEntity, String.class);
        } catch (IOException e) {
            throw e;
        }
    }

    private String getPrefixUrl() {
        return SDKConfigMgr.getServerHost() + prefixUrl;
    }
}
