package com.xylink.sdk.log;

import com.xylink.config.SDKConfigMgr;
import com.xylink.log.XyLinkLogType;
import com.xylink.model.SdkCloudMeetingRoomRequest;
import com.xylink.model.SdkMeeting;
import com.xylink.sdk.conferenceControl.CreateMeetingApi;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.core.config.ConfigurationSource;
import org.apache.logging.log4j.core.config.Configurator;
import org.junit.Test;

import java.io.*;
import java.net.URISyntaxException;

/**
 * @Description: 使用 xyLink-jar 的日志框架的示例
 * 推荐版本: log4j2 - 2.17.2
 */
public class Test_log4j2 {

    private String enterpriseId = "xxx";
    private String token = "xxx";
    private String clientId = "xxx";
    private String clientSecret = "xxx";
    private String host = "xxx";
    private String fileLocation  = "/xxx/xxx/xxx/log4j.properties";

    @Test
    public void test() throws IOException, URISyntaxException {

        //加载日志配置文件(web项目无需手动加载, 可忽略该步骤 SpringBoot自动装配即可)
        File file = new File(fileLocation);
        BufferedInputStream inputStream = new BufferedInputStream(new FileInputStream(file));
        ConfigurationSource source = new ConfigurationSource(inputStream);
        Configurator.initialize(null, source);

        //非web工程获取logger的方式
        Logger logger = LogManager.getLogger();

        //令xyLink-jar 输出打印到日志文件
        //xyLink-jar 初始化配置
        //签名1.0
        SDKConfigMgr.setServerHost(host);
        SDKConfigMgr.setXyLinkLogType(XyLinkLogType.Log4j2);

        //签名2.0+ (initSDKConfig)
        //SDKConfigMgr.initSDKConfig(host, clientId, clientSecret, enterpriseId, XyLinkLogType.Log4j2);

        //后续逻辑直接调用sdkJar即可, sdkJar会使用父项目的日志配置,
        //例如: 创建SDK云会议室接口
        CreateMeetingApi createMeetingApi = new CreateMeetingApi();
        SdkCloudMeetingRoomRequest request = new SdkCloudMeetingRoomRequest();
        request.setMeetingName("log4j2-test");

        SdkMeeting meetingResult = createMeetingApi.createMeetingV2(enterpriseId, token, request);
        System.out.println(meetingResult);

        //使用父项目的logger打印, logger是从父项目中获取的, 具备父项目的一切配置
        logger.info("project log: "+meetingResult);


    }

}
